<script setup>
import { computed, onMounted, onUnmounted, ref } from 'vue';

const props = defineProps({
    align: {
        type: String,
        default: 'right',
    },
    padding: {
        type: String,
        default: 'none',
    },
    width: {
        type: String,
        default: '40',
    },
    identifier: {
        type: String,
        default: '0',
    },
    contentClasses: {
        type: Array,
        default: () => ['py-1.5', 'bg-white'],
    },
});

let open = ref(false);

const closeOnEscape = (e) => {
    if (open.value && e.key === 'Escape') {
        open.value = false;
    }
};

onMounted(() => document.addEventListener('keydown', closeOnEscape));
onUnmounted(() => document.removeEventListener('keydown', closeOnEscape));

const widthClass = computed(() => {
    return {
        '32': 'w-32',
        '40': 'w-40',
    }[props.width.toString()];
});

const alignmentClasses = computed(() => {
    if (props.align === 'left') {
        return 'origin-top-left left-0';
    }

    if (props.align === 'right') {
        return 'origin-top-right right-0';
    }

    return 'origin-top';
});

const spacingClasses = computed(() => {
    if (props.padding != 'none') {
        return 'mt-' + props.padding ;
    }

    return 'mt-1';
});
</script>

<template>
    <div class="relative h-full">
        <div @click="open = ! open" class="h-full w-full">
            <slot name="trigger" class="flex justify-center items-center"/>
        </div>

        <!-- Full Screen Dropdown Overlay -->
        <div v-show="open" class="fixed inset-0 z-[110]" @click="open = false" />

        <transition
            enter-active-class="transition ease-out duration-200"
            enter-from-class="transform opacity-0 scale-95"
            enter-to-class="transform opacity-100 scale-100"
            leave-active-class="transition ease-in duration-75"
            leave-from-class="transform opacity-100 scale-100"
            leave-to-class="transform opacity-0 scale-95"
        >
            <div
                v-show="open"
                class="absolute rounded-md bg-transparent shadow-lg z-[110]"
                :class="[widthClass, alignmentClasses, spacingClasses]"
                style="display: none;"
                @click="open = false"
            >
                <div v-if="identifier!='1'" class="bg-blue-opa-navbar rounded-md ring-1 ring-black ring-opacity-5" :class="contentClasses">
                    <slot name="content"></slot>
                </div>
                <div v-if="identifier=='1'" class="bg-blue-opa-navbar rounded-md ring-1 ring-black ring-opacity-5 md:hidden" :class="contentClasses">
                    <slot name="content"></slot>
                </div>
            </div>
        </transition>
    </div>
</template>
